@@ -5,14 +5,15 @@ import os
 
 import anvil.server
 import pkg_resources
+from connect.client import AsyncConnectClient, ConnectClient
 from fastapi import APIRouter
 
-from connect.client import AsyncConnectClient, ConnectClient
 from connect.eaas.core.constants import (
     ACCOUNT_SETTINGS_PAGE_ATTR_NAME,
     ADMIN_PAGES_ATTR_NAME,
     ANVIL_CALLABLE_ATTR_NAME,
     ANVIL_KEY_VAR_ATTR_NAME,
+    DEVOPS_PAGES_ATTR_NAME,
     EVENT_INFO_ATTR_NAME,
     GUEST_ENDPOINT_ATTR_NAME,
     MODULE_PAGES_ATTR_NAME,
@@ -26,7 +27,7 @@ from connect.eaas.core.decorators import router
 class ApplicationBase:
 
     @classmethod
-    def get_descriptor(cls):  # pragma: no cover
+    def get_descriptor(cls) -> dict:  # pragma: no cover
         """
         Returns the **extension.json** extension descriptor.
 
@@ -52,7 +53,7 @@ class ApplicationBase:
         )
 
     @classmethod
-    def get_variables(cls):
+    def get_variables(cls) -> dict:
         """
         Inspects the Events Application class returning the list of environment
         variables declared using the `@variables` class decorator.
@@ -77,25 +78,7 @@ class ApplicationBase:
         return getattr(cls, VARIABLES_INFO_ATTR_NAME, [])
 
 
-class EventsApplicationBase(ApplicationBase):
-    """Base class to implements an Events Application."""
-
-    def __init__(
-        self,
-        client,
-        logger,
-        config,
-        installation_client=None,
-        installation=None,
-        context=None,
-    ):
-        self.client = client
-        self.logger = logger
-        self.config = config
-        self.installation_client = installation_client
-        self.installation = installation
-        self.context = context
-
+class InstallationAdminClientMixin:
     def get_installation_admin_client(self, installation_id):
         data = (
             self.client('devops')
@@ -127,8 +110,28 @@ class EventsApplicationBase(ApplicationBase):
             logger=self.client.logger,
         )
 
+
+class EventsApplicationBase(ApplicationBase, InstallationAdminClientMixin):
+    """Base class to implements an Events Application."""
+
+    def __init__(
+        self,
+        client,
+        logger,
+        config,
+        installation_client=None,
+        installation=None,
+        context=None,
+    ):
+        self.client = client
+        self.logger = logger
+        self.config = config
+        self.installation_client = installation_client
+        self.installation = installation
+        self.context = context
+
     @classmethod
-    def get_events(cls):
+    def get_events(cls) -> dict:
         """
         Inspects the Events Application class for methods
         decorated with the `@event` decorator and return a list of
@@ -149,7 +152,7 @@ class EventsApplicationBase(ApplicationBase):
         return cls._get_methods_info(EVENT_INFO_ATTR_NAME)
 
     @classmethod
-    def get_schedulables(cls):
+    def get_schedulables(cls) -> dict:
         """
         Inspects the Events Application class for methods
         decorated with the `@schedulable` decorator and return a list of
@@ -201,7 +204,7 @@ class WebApplicationBase(ApplicationBase):
         return None
 
     @classmethod
-    def get_routers(cls):
+    def get_routers(cls) -> tuple:
         """
         Inspect the Web Application class for routes and return a tuple
         or two routers, the first one contains authenticated API routes,
@@ -233,6 +236,9 @@ class WebApplicationBase(ApplicationBase):
         if hasattr(cls, ADMIN_PAGES_ATTR_NAME):
             ui_modules['admins'] = getattr(cls, ADMIN_PAGES_ATTR_NAME)
 
+        if hasattr(cls, DEVOPS_PAGES_ATTR_NAME):
+            ui_modules['devops'] = getattr(cls, DEVOPS_PAGES_ATTR_NAME)
+
         return ui_modules
 
 
@@ -250,7 +256,7 @@ class AnvilApplicationBase(ApplicationBase):
         self.installation = installation
 
     @classmethod
-    def get_anvil_key_variable(cls):
+    def get_anvil_key_variable(cls) -> str:
         """
         Returns the name of the environment variable that
         stores the Anvil Server Uplink key.
@@ -303,35 +309,54 @@ class AnvilApplicationBase(ApplicationBase):
                 anvil.server.callable(fn)
 
 
-class TransformationBase:
+class TransformationsApplicationBase(ApplicationBase, InstallationAdminClientMixin):
 
     def __init__(
-            self,
-            input_columns,
-            output_columns,
-            stream,
-            client,
-            config,
-            logger,
-            transformation_settings=None,
-            installation_client=None,
-            installation=None,
-            cache=None,
+        self,
+        client,
+        logger,
+        config,
+        installation_client=None,
+        installation=None,
+        context=None,
+        transformation_request=None,
     ):
         self.client = client
-        self.config = config
         self.logger = logger
-
+        self.config = config
         self.installation_client = installation_client
         self.installation = installation
-
-        self.input_columns = input_columns
-        self.output_columns = output_columns
-        self.stream = stream
-
-        self.transformation_settings = transformation_settings
-        self.cache = cache
+        self.context = context
+        self.transformation_request = transformation_request
 
     @classmethod
-    def get_transformation_info(cls):
-        return getattr(cls, TRANSFORMATION_ATTR_NAME, None)
+    def get_transformations(cls) -> dict:
+        """
+        Inspects the Transformations Application class for methods
+        decorated with the `@transformation` decorator and return a list of
+        objects like in the following example:
+
+        !!! example
+
+            ``` python
+            [
+                {
+                    'method': 'split_by_delimiter',
+                    'name': 'Split column by delimiter',
+                    'description': 'This schedulable refresh the GCP OAuth toke',
+                },
+            ]
+            ```
+        """
+        return cls._get_methods_info(TRANSFORMATION_ATTR_NAME)
+
+    @classmethod
+    def _get_methods_info(cls, attr_name):
+        info = []
+        members = inspect.getmembers(cls)
+        for _, value in members:
+            if not (inspect.isfunction(value) or inspect.iscoroutinefunction(value)):
+                continue
+            if hasattr(value, attr_name):
+                info.append(getattr(value, attr_name))
+        return info
